==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Hejmpaĝo',
	'article' => 'Artikolo',
	'articles' => 'Artikoloj',
	'articles_auteur' => 'Artikoloj de tiu aŭtoro',
	'articles_populaires' => 'La plej popularaj artikoloj',
	'articles_rubrique' => 'Artikoloj el tiu rubriko',
	'aucun_article' => 'Neniu artikolo ĉe tiu adreso',
	'aucun_auteur' => 'Neniu aŭtoro por tiu adreso',
	'aucun_site' => 'Neniu retejo ĉe tiu adreso',
	'aucune_breve' => 'Neniu fulm-informo ĉe tiu adreso',
	'aucune_rubrique' => 'Neniu rubriko ĉe tiu adreso',
	'auteur' => 'Aŭtoro',
	'autres' => 'Aliaj',
	'autres_breves' => 'Neniu fulm-informo',
	'autres_groupes_mots_clefs' => 'Aliaj grupoj de ŝlosilvortoj',
	'autres_sites' => 'Aliaj retejoj',

	// B
	'bonjour' => 'Bonan tagon',

	// C
	'commenter_site' => 'Komenti tiun retejon',
	'contact' => 'Kontakto',
	'copie_document_impossible' => 'Estas neeble kopii la dokumenton',

	// D
	'date' => 'Dato',
	'dernier_ajout' => 'Lasta aldono',
	'dernieres_breves' => 'Lastaj fulm-informoj',
	'derniers_articles' => 'Lastaj artikoloj',
	'derniers_commentaires' => 'Lastaj komentoj',
	'derniers_messages_forum' => 'Lastaj mesaĝoj publikigitaj en la forumoj',

	// E
	'edition_mode_texte' => 'Teksta eldono de',
	'en_reponse' => 'Responde al :',
	'en_resume' => 'Resume',
	'envoyer_message' => 'Sendi mesaĝon',
	'espace_prive' => 'Privata spaco',

	// F
	'formats_acceptes' => 'Formatoj akceptitaj : @formats@.',

	// H
	'hierarchie_site' => 'Hierarkio de la retejo',

	// J
	'jours' => 'tagoj',

	// L
	'lien_connecter' => 'Ensaluti',

	// M
	'meme_auteur' => 'De la sama aŭtoro',
	'meme_rubrique' => 'En la sama rubriko',
	'memes_auteurs' => 'De samaj aŭtoroj',
	'message' => 'Mesaĝo',
	'messages_forum' => 'Mesaĝoj',
	'messages_recents' => 'La plej freŝaj forum-mesaĝoj',
	'mots_clef' => 'Ŝlosilvorto',
	'mots_clefs' => 'Ŝlosilvortoj',
	'mots_clefs_meme_groupe' => 'Ŝlosilvortoj en la sama grupo',

	// N
	'navigation' => 'Retumado',
	'nom' => 'Nomo',
	'nouveautes' => 'La novaĵoj',
	'nouveautes_web' => 'Novaĵoj ĉe la reto',
	'nouveaux_articles' => 'Novaj artikoloj',
	'nouvelles_breves' => 'Novaj fulm-informoj',

	// P
	'page_precedente' => 'antaŭa paĝo',
	'page_suivante' => 'sekvanta paĝo',
	'par_auteur' => 'de ',
	'participer_site' => 'Por partopreni la vivon de tiu retejo kaj proponi viajn propajn artikolojn, registriĝu ĉi sube. Vi tuj ricevos retleteron indikante ensalutilojn por eniri la privatan spacon.',
	'plan_site' => 'Mapo de la retejo',
	'popularite' => 'Populareco',
	'poster_message' => 'Sendi mesaĝon',
	'proposer_site' => 'Vi povas proponi retejon aldonotan al tiu rubriko :',

	// R
	'repondre_article' => 'Respondi al tiu artikolo',
	'repondre_breve' => 'Respondi al tiu fulm-informo',
	'resultats_recherche' => 'Serĉo-rezultoj',
	'retour_debut_forums' => 'Reen al forumoj-komenco',
	'rubrique' => 'Rubriko',
	'rubriques' => 'Rubrikoj',

	// S
	'signatures_petition' => 'Subskriboj',
	'site_realise_avec_spip' => 'Retejo pelata de SPIP',
	'sites_web' => 'Retejoj',
	'sous_rubriques' => 'Sub-rubrikoj',
	'spam' => 'Trudmesaĝo',
	'suite' => 'sekvo',
	'sur_web' => 'Ĉe la reto',
	'syndiquer_rubrique' => 'Abonrilatigi tiun rubrikon',
	'syndiquer_site' => 'Abonrilatigi la tutan retejon',

	// T
	'texte_lettre_information' => 'Jen la reteja inform-letero',
	'texte_lettre_information_2' => 'Tiu letero enkalkulas la novaĵojn publikigitajn de',

	// V
	'ver_imprimer' => 'Elprintota versio',
	'voir_en_ligne' => 'Vidi konektite',
	'voir_squelette' => 'vidi la skeleton de tiu paĝo'
);

==> spip_4.4.4+dfsg.orig.tar.xz: ecrire/lang/public_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public_?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Hejmpaĝo',
	'article' => 'Artikolo',
	'articles' => 'Artikoloj',
	'articles_auteur' => 'Artikoloj de tiu aŭtoro',
	'articles_populaires' => 'La plej popularaj artikoloj',
	'articles_rubrique' => 'Artikoloj el tiu rubriko',
	'aucun_article' => 'Neniu artikolo ĉe tiu adreso',
	'aucun_auteur' => 'Neniu aŭtoro por tiu adreso',
	'aucun_site' => 'Neniu retejo ĉe tiu adreso',
	'aucune_breve' => 'Neniu fulm-informo ĉe tiu adreso',
	'aucune_rubrique' => 'Neniu rubriko ĉe tiu adreso',
	'auteur' => 'Aŭtoro',
	'autres' => 'Aliaj',
	'autres_breves' => 'Neniu fulm-informo',
	'autres_groupes_mots_clefs' => 'Aliaj grupoj de ŝlosilvortoj',
	'autres_sites' => 'Aliaj retejoj',

	// B
	'bonjour' => 'Bonan tagon',

	// C
	'commenter_site' => 'Komenti tiun retejon',
	'contact' => 'Kontakto',
	'copie_document_impossible' => 'Estas neeble kopii la dokumenton',

	// D
	'date' => 'Dato',
	'dernier_ajout' => 'Lasta aldono',
	'dernieres_breves' => 'Lastaj fulm-informoj',
	'derniers_articles' => 'Lastaj artikoloj',
	'derniers_commentaires' => 'Lastaj komentoj',
	'derniers_messages_forum' => 'Lastaj mesaĝoj publikigitaj en la forumoj',

	// E
	'edition_mode_texte' => 'Teksta eldono de',
	'en_reponse' => 'Responde al :',
	'en_resume' => 'Resume',
	'envoyer_message' => 'Sendi mesaĝon',
	'espace_prive' => 'Privata spaco',

	// F
	'formats_acceptes' => 'Formatoj akceptitaj : @formats@.',

	// H
	'hierarchie_site' => 'Hierarkio de la retejo',

	// J
	'jours' => 'tagoj',

	// L
	'lien_connecter' => 'Ensaluti',

	// M
	'meme_auteur' => 'De la sama aŭtoro',
	'meme_rubrique' => 'En la sama rubriko',
	'memes_auteurs' => 'De samaj aŭtoroj',
	'message' => 'Mesaĝo',
	'messages_forum' => 'Mesaĝoj',
	'messages_recents' => 'La plej freŝaj forum-mesaĝoj',
	'mots_clef' => 'Ŝlosilvorto',
	'mots_clefs' => 'Ŝlosilvortoj',
	'mots_clefs_meme_groupe' => 'Ŝlosilvortoj en la sama grupo',

	// N
	'navigation' => 'Retumado',
	'nom' => 'Nomo',
	'nouveautes' => 'La novaĵoj',
	'nouveautes_web' => 'Novaĵoj ĉe la reto',
	'nouveaux_articles' => 'Novaj artikoloj',
	'nouvelles_breves' => 'Novaj fulm-informoj',

	// P
	'page_precedente' => 'antaŭa paĝo',
	'page_suivante' => 'sekvanta paĝo',
	'par_auteur' => 'de ',
	'participer_site' => 'Por partopreni la vivon de tiu retejo kaj proponi viajn propajn artikolojn, registriĝu ĉi sube. Vi tuj ricevos retleteron indikante ensalutilojn por eniri la privatan spacon.',
	'plan_site' => 'Mapo de la retejo',
	'popularite' => 'Populareco',
	'poster_message' => 'Sendi mesaĝon',
	'proposer_site' => 'Vi povas proponi retejon aldonotan al tiu rubriko :',

	// R
	'repondre_article' => 'Respondi al tiu artikolo',
	'repondre_breve' => 'Respondi al tiu fulm-informo',
	'resultats_recherche' => 'Serĉo-rezultoj',
	'retour_debut_forums' => 'Reen al forumoj-komenco',
	'rss_abonnement_titre' => 'Abonu',
	'rss_abonnement_titre_page' => 'Aboni al',
	'rss_explication_titre' => 'Kio estas RSS-fluo ?',
	'rubrique' => 'Rubriko',
	'rubriques' => 'Rubrikoj',

	// S
	'signatures_petition' => 'Subskriboj',
	'site_realise_avec_spip' => 'Retejo pelata de SPIP',
	'sites_web' => 'Retejoj',
	'sous_rubriques' => 'Sub-rubrikoj',
	'spam' => 'Trudmesaĝo',
	'suite' => 'sekvo',
	'sur_web' => 'Ĉe la reto',
	'syndiquer_rubrique' => 'Abonrilatigi tiun rubrikon',
	'syndiquer_site' => 'Abonrilatigi la tutan retejon',

	// T
	'texte_lettre_information' => 'Jen la reteja inform-letero',
	'texte_lettre_information_2' => 'Tiu letero enkalkulas la novaĵojn publikigitajn de',

	// V
	'ver_imprimer' => 'Elprintota versio',
	'voir_en_ligne' => 'Vidi konektite',
	'voir_squelette' => 'vidi la skeleton de tiu paĝo',
];
